Work with analysis results — SLiCAP 4.0.7 documentation

# Work with analysis results

SLiCAP output displayed on this manual page, is generated with the script: `math.py`, imported by `Manual.py`.

     1#!/usr/bin/env python3
     2# -*- coding: utf-8 -*-
     3
     4"""
     5math.py: SLiCAP scripts for the HTML help file
     6"""
     7import SLiCAP as sl
     8import sympy as sp
     9
    10###############################################################################
    11# work with analysis results
    12###############################################################################

Python offers numerous packages for processing SLiCAP results and deriving and solving design equations. Aside from that SLiCAP offers the user a number of built-in:

1. math functions

2. plot functions